pub enum AstExpr {
Show 35 variants
As(IdentWithToken, Shared<Node>),
Block(Program),
Call(IdentWithToken, SmallVec<[Shared<Node>; 4]>),
CallDynamic(Shared<Node>, SmallVec<[Shared<Node>; 4]>),
Def(IdentWithToken, Params, Program),
Macro(IdentWithToken, Params, Shared<Node>),
Fn(Params, Program),
Let(Pattern, Shared<Node>),
Loop(Program),
Var(Pattern, Shared<Node>),
Assign(IdentWithToken, Shared<Node>),
And(Vec<Shared<Node>>),
Or(Vec<Shared<Node>>),
Literal(Literal),
Ident(IdentWithToken),
InterpolatedString(Vec<StringSegment>),
Selector(Selector),
SelectorChain(SmallVec<[Selector; 4]>),
SelectorCall(Selector, SmallVec<[Shared<Node>; 4]>),
While(Shared<Node>, Program),
Foreach(IdentWithToken, Shared<Node>, Program),
If(SmallVec<[(Option<Shared<Node>>, Shared<Node>); 4]>),
Match(Shared<Node>, SmallVec<[MatchArm; 4]>),
Include(Literal),
Import(Literal),
Module(IdentWithToken, Program),
QualifiedAccess(Vec<IdentWithToken>, AccessTarget),
Self_,
Nodes,
Paren(Shared<Node>),
Quote(Shared<Node>),
Unquote(Shared<Node>),
Try(Shared<Node>, Shared<Node>),
Break(Option<Shared<Node>>),
Continue,
}Variants
As(IdentWithToken, Shared<Node>)
Block(Program)
Call(IdentWithToken, SmallVec<[Shared<Node>; 4]>)
CallDynamic(Shared<Node>, SmallVec<[Shared<Node>; 4]>)
Def(IdentWithToken, Params, Program)
Macro(IdentWithToken, Params, Shared<Node>)
Fn(Params, Program)
Let(Pattern, Shared<Node>)
Loop(Program)
Var(Pattern, Shared<Node>)
Assign(IdentWithToken, Shared<Node>)
And(Vec<Shared<Node>>)
Or(Vec<Shared<Node>>)
Literal(Literal)
Ident(IdentWithToken)
InterpolatedString(Vec<StringSegment>)
Selector(Selector)
SelectorChain(SmallVec<[Selector; 4]>)
A sequence of selectors merged by the optimizer to reduce pipeline overhead.
Equivalent to applying each selector in order, but evaluated in a single
eval_expr call instead of N separate pipeline steps.
SelectorCall(Selector, SmallVec<[Shared<Node>; 4]>)
A selector with runtime-evaluated arguments for filtered matching.
Supports .h(1..2), .h(1, 2), .code("rust"), etc.
While(Shared<Node>, Program)
Foreach(IdentWithToken, Shared<Node>, Program)
If(SmallVec<[(Option<Shared<Node>>, Shared<Node>); 4]>)
Match(Shared<Node>, SmallVec<[MatchArm; 4]>)
Include(Literal)
Import(Literal)
Module(IdentWithToken, Program)
QualifiedAccess(Vec<IdentWithToken>, AccessTarget)
Self_
Nodes
Paren(Shared<Node>)
Quote(Shared<Node>)
Unquote(Shared<Node>)
Try(Shared<Node>, Shared<Node>)
Break(Option<Shared<Node>>)
Continue