TokenKind

Enum TokenKind 

pub enum TokenKind {
Show 82 variants And, Arrow, As, Convert, Asterisk, BoolLiteral(bool), BytesLiteral(Vec<u8>), Break, Catch, Coalesce, Colon, DoubleColon, DoubleSlashEqual, Comma, Comment(String), Continue, Def, Do, Elif, Else, End, Env(SmolStr), Eof, Equal, EqEq, Fn, Foreach, Gt, Gte, Ident(SmolStr), If, Include, InterpolatedString(Vec<StringSegment>), Import, LBrace, LBracket, Let, LeftShift, Loop, Lt, Lte, Macro, Match, Module, Minus, MinusEqual, NeEq, NewLine, Nodes, None, Not, NumberLiteral(Number), Or, Percent, PercentEqual, Pipe, PipeEqual, Plus, PlusEqual, Question, Quote, RBrace, DoubleDot, RBracket, RightShift, RParen, Selector(SmolStr), Self_, SemiColon, Slash, SlashEqual, StringLiteral(String), StarEqual, Tab(usize), TildeEqual, NotTildeEqual, Try, Unquote, Whitespace(usize), While, LParen, Var,
}
Represents the kind of a token in the mq language.

TokenKind variants are sorted alphabetically for maintainability.

Variants



And



Arrow



As



Convert



Asterisk



BoolLiteral(bool)



BytesLiteral(Vec<u8>)



Break



Catch



Coalesce



Colon



DoubleColon



DoubleSlashEqual



Comma



Comment(String)



Continue



Def



Do



Elif



Else



End



Env(SmolStr)



Eof



Equal



EqEq



Fn



Foreach



Gt



Gte



Ident(SmolStr)



If



Include



InterpolatedString(Vec<StringSegment>)



Import



LBrace



LBracket



Let



LeftShift



Loop



Lt



Lte



Macro



Match



Module



Minus



MinusEqual



NeEq



NewLine



Nodes



None



Not



NumberLiteral(Number)



Or



Percent



PercentEqual



Pipe



PipeEqual



Plus



PlusEqual



Question



Quote



RBrace



DoubleDot



RBracket



RightShift



RParen



Selector(SmolStr)



Self_



SemiColon



Slash



SlashEqual



StringLiteral(String)



StarEqual



Tab(usize)



TildeEqual



NotTildeEqual



Try



Unquote



Whitespace(usize)



While



LParen



Var