pub struct Arena<T> { /* private fields */ }Expand description
An arena allocator for efficiently storing and accessing elements.
The arena allocates elements sequentially and returns type-safe ArenaIds
that can be used to retrieve elements later. This pattern provides fast allocation
and cache-friendly access.
Implementations
Sourceimpl<T: Clone + PartialEq> Arena<T>
impl<T: Clone + PartialEq> Arena<T>
Sourcepub fn alloc(&mut self, value: T) -> ArenaId<T>
pub fn alloc(&mut self, value: T) -> ArenaId<T>
Allocates a value in the arena and returns its identifier.
Sourcepub fn contains(&self, value: T) -> bool
pub fn contains(&self, value: T) -> bool
Returns true if the arena contains the specified value.
Sourcepub fn extend_from_slice(&mut self, items: &[T])
pub fn extend_from_slice(&mut self, items: &[T])
Extends the arena by cloning elements from a slice.